==> foundation-ui-components-1.7.0.tgz: package/src/common/card/specs/NsHeroCardLevel1.spec.tsx <==
import React from 'react';
import { render, screen } from '@testing-library/react';
import userEvent from '@testing-library/user-event';
import NsHeroCardLevel1 from '../NsHeroCardLevel1';

describe('NsHeroCardLevel1 component', () => {
    const props = {
        cardLink: {
            href: 'https://www.forceforgood.org/',
            title: 'SHOP NOW',
        },
        text: 'A skin ready for winter',
        body: 'We have brought these discoveries to life through our powerful skin care products and supplements.',
        backgroundImageUrl:
            'https://media.nuskin.com/m/9734240cc191163/webimage-lash-brow-serum-carousel-image-launch.png',
        backgroundImageAlt: 'lash brow serum carousel',
        onClick: jest.fn(),
        additionalProps: {
            testid: 'hero-card-level-1',
        },
    };

    it('1. renders with correct content and styles', () => {
        render(<NsHeroCardLevel1 {...props} />);

        const heroCard = screen.getByTestId('hero-card-level-1');
        expect(heroCard).toBeInTheDocument();

        const shopNowLink = screen.getByText('SHOP NOW');
        expect(shopNowLink).toBeInTheDocument();
    });

    it('2. calls onClick when the card is clicked', () => {
        render(<NsHeroCardLevel1 {...props} />);

        const heroCard = screen.getByTestId('hero-card-level-1');
        userEvent.click(heroCard);

        expect(props.onClick).toHaveBeenCalled();
    });

    it('3. applies hover styles on mouseover', () => {
        render(<NsHeroCardLevel1 {...props} />);

        const heroCard = screen.getByTestId('hero-card-level-1');
        userEvent.hover(heroCard);
    });
});

==> foundation-ui-components-1.8.1.tgz: package/src/common/card/specs/NsHeroCardLevel1.spec.tsx <==
import React from 'react';
import { render, screen } from '@testing-library/react';
import userEvent from '@testing-library/user-event';
import NsHeroCardLevel1 from '../NsHeroCardLevel1';

describe('NsHeroCardLevel1 component', () => {
    const props = {
        cardLink: {
            href: 'https://www.forceforgood.org/',
            title: 'SHOP NOW',
        },
        text: 'A skin ready for winter',
        body: 'We have brought these discoveries to life through our powerful skin care products and supplements.',
        backgroundImageUrl:
            'https://media.nuskin.com/m/9734240cc191163/webimage-lash-brow-serum-carousel-image-launch.png',
        backgroundImageAlt: 'lash brow serum carousel',
        onClick: jest.fn(),
        additionalProps: {
            testid: 'hero-card-level-1',
        },
    };

    it('1. renders with correct content and styles', () => {
        render(<NsHeroCardLevel1 {...props} />);

        const heroCard = screen.getByTestId('hero-card-level-1');
        expect(heroCard).toBeInTheDocument();

        const shopNowLink = screen.getByText('SHOP NOW');
        expect(shopNowLink).toBeInTheDocument();
    });

    it.skip('2. calls onClick when the card is clicked', () => {
        render(<NsHeroCardLevel1 {...props} />);

        const heroCard = screen.getByTestId('hero-card-level-1');
        userEvent.click(heroCard);

        expect(props.onClick).toHaveBeenCalled();
    });

    it('3. applies hover styles on mouseover', () => {
        render(<NsHeroCardLevel1 {...props} />);

        const heroCard = screen.getByTestId('hero-card-level-1');
        userEvent.hover(heroCard);
    });
});
